
import { Subject } from 'rxjs';
import { GridView9Base } from '@/studio-core';
import HROrgAddressService from '@/service/hrorg-address/hrorg-address-service';
import HROrgAddressAuthService from '@/authservice/hrorg-address/hrorg-address-auth-service';
import GridView9Engine from '@engine/view/grid-view9-engine';
import HROrgAddressUIService from '@/uiservice/hrorg-address/hrorg-address-ui-service';
import CodeListService from "@service/app/codelist-service";


/**
 * 组织地址嵌入组织视图基类
 *
 * @export
 * @class HROrgAddressV_001Base
 * @extends {GridView9Base}
 */
export class HROrgAddressV_001Base extends GridView9Base {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HROrgAddressV_001Base
     */
    protected appDeName: string = 'hrorgaddress';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HROrgAddressV_001Base
     */
    protected appDeKey: string = 'hrorgaddressid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HROrgAddressV_001Base
     */
    protected appDeMajor: string = 'hrorgaddressname';

    /**
     * 实体服务对象
     *
     * @type {HROrgAddressService}
     * @memberof HROrgAddressV_001Base
     */
    protected appEntityService: HROrgAddressService = new HROrgAddressService;

    /**
     * 实体权限服务对象
     *
     * @type HROrgAddressUIService
     * @memberof HROrgAddressV_001Base
     */
    public appUIService: HROrgAddressUIService = new HROrgAddressUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HROrgAddressV_001Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HROrgAddressV_001Base
     */
    protected model: any = {
        srfCaption: 'entities.hrorgaddress.views.v_001.caption',
        srfTitle: 'entities.hrorgaddress.views.v_001.title',
        srfSubTitle: 'entities.hrorgaddress.views.v_001.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HROrgAddressV_001Base
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '3110aca6f6c27996e9874cfb924c569f';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HROrgAddressV_001Base
     */
    public engine: GridView9Engine = new GridView9Engine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HROrgAddressV_001Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            opendata: (args: any[],fullargs?:any[],params?: any, $event?: any, xData?: any) => {
                this.opendata(args,fullargs, params, $event, xData);
            },
            grid: this.$refs.grid,
            keyPSDEField: 'hrorgaddress',
            majorPSDEField: 'hrorgaddressname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrgAddressV_001Base
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrgAddressV_001Base
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrgAddressV_001Base
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrgAddressV_001Base
     */
    public grid_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'remove', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HROrgAddressV_001Base
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * 打开编辑数据视图
     *
     * @param {any[]} args
     * @param {*} [params]
     * @param {*} [fullargs]
     * @param {*} [$event]
     * @param {*} [xData]
     * @memberof HROrgAddressV_001
     */
    public opendata(args: any[],fullargs?:any[],params?: any, $event?: any, xData?: any) {
        const localContext: any = null;
        const localViewParam: any =null;
        const data: any = {};
        let tempContext = JSON.parse(JSON.stringify(this.context));
        if(args.length >0){
            Object.assign(tempContext,args[0]);
        }
        let deResParameters: any[] = [];
        if(tempContext.hrlegal && true){
            deResParameters = [
            { pathName: 'hrlegals', parameterName: 'hrlegal' },
            ]
        }
        const parameters: any[] = [
            { pathName: 'hrorgaddresses', parameterName: 'hrorgaddress' },
        ];
        const _this: any = this;
        const openDrawer = (view: any, data: any) => {
            let container: Subject<any> = this.$appdrawer.openDrawer(view, tempContext, data);
            container.subscribe((result: any) => {
                if (!result || !Object.is(result.ret, 'OK')) {
                    return;
                }
                if (!xData || !(xData.refresh instanceof Function)) {
                    return;
                }
                xData.refresh(result.datas);
            });
        }
        const view: any = {
            viewname: 'hrorg-address-edit-view', 
            height: 0, 
            width: 600,  
            title: this.$t('entities.hrorgaddress.views.editview.title'),
            placement: 'DRAWER_RIGHT',
        };
        openDrawer(view, data);
    }



    /**
     * 是否单选
     *
     * @protected
     * @type {boolean}
     * @memberof HROrgAddressV_001Base
     */
    protected isGridSingleSelect: boolean = true;

    /**
     * 表格行数据默认激活模式
     * 0 不激活
     * 1 单击激活
     * 2 双击激活
     *
     * @protected
     * @type {(0 | 1 | 2)}
     * @memberof HROrgAddressV_001Base
     */
    protected gridRowActiveMode: 0 | 1 | 2 = 0;
}