import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import HRArchivesService from '@/service/hrarchives/hrarchives-service';
import HRArchivesAuthService from '@/authservice/hrarchives/hrarchives-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import HRArchivesUIService from '@/uiservice/hrarchives/hrarchives-ui-service';

/**
 * 档案信息视图基类
 *
 * @export
 * @class HRArchivesV_003Base
 * @extends {EditViewBase}
 */
export class HRArchivesV_003Base extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_003Base
     */
    protected appDeName: string = 'hrarchives';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_003Base
     */
    protected appDeKey: string = 'hrarchivesid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_003Base
     */
    protected appDeMajor: string = 'hrarchivesname';

    /**
     * 实体服务对象
     *
     * @type {HRArchivesService}
     * @memberof HRArchivesV_003Base
     */
    protected appEntityService: HRArchivesService = new HRArchivesService;

    /**
     * 实体权限服务对象
     *
     * @type HRArchivesUIService
     * @memberof HRArchivesV_003Base
     */
    public appUIService: HRArchivesUIService = new HRArchivesUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRArchivesV_003Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_003Base
     */
    protected model: any = {
        srfCaption: 'entities.hrarchives.views.v_003.caption',
        srfTitle: 'entities.hrarchives.views.v_003.title',
        srfSubTitle: 'entities.hrarchives.views.v_003.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_003Base
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '4577fe920c1f8dc9da44a0cab28ca33b';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRArchivesV_003Base
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRArchivesV_003Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'hrarchives',
            majorPSDEField: 'hrarchivesname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_003Base
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_003Base
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_003Base
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}