import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, GridControlBase } from '@/studio-core';
import HRArchivesService from '@/service/hrarchives/hrarchives-service';
import GRID_001Service from './grid-001-grid-service';
import HRArchivesUIService from '@/uiservice/hrarchives/hrarchives-ui-service';
import { FormItemModel } from '@/model/form-detail';


/**
 * grid部件基类
 *
 * @export
 * @class GridControlBase
 * @extends {GRID_001GridBase}
 */
export class GRID_001GridBase extends GridControlBase {

    /**
     * 获取部件类型
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected controlType: string = 'GRID';

    /**
     * 建构部件服务对象
     *
     * @type {GRID_001Service}
     * @memberof GRID_001GridBase
     */
    public service: GRID_001Service = new GRID_001Service({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {HRArchivesService}
     * @memberof GRID_001GridBase
     */
    public appEntityService: HRArchivesService = new HRArchivesService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeName: string = 'hrarchives';

    /**
     * 应用实体中文名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeLogicName: string = '档案信息';

    /**
     * 界面UI服务对象
     *
     * @type {HRArchivesUIService}
     * @memberof GRID_001Base
     */  
    public appUIService:HRArchivesUIService = new HRArchivesUIService(this.$store);

    /**
     * 界面行为模型
     *
     * @type {*}
     * @memberof GRID_001Base
     */  
    public ActionModel: any = {
    };

    /**
     * 本地缓存标识
     *
     * @protected
     * @type {string}
     * @memberof GRID_001Base
     */
    protected localStorageTag: string = 'hrarchives_grid_001_grid';

    /**
     * 所有列成员
     *
     * @type {any[]}
     * @memberof GRID_001GridBase
     */
    public allColumns: any[] = [
        {
            name: 'archivescode',
            label: '档案编号',
            langtag: 'entities.hrarchives.grid_001_grid.columns.archivescode',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'hrorganizationname',
            label: '档案管理单位',
            langtag: 'entities.hrarchives.grid_001_grid.columns.hrorganizationname',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'archivesplace',
            label: '档案保管地',
            langtag: 'entities.hrarchives.grid_001_grid.columns.archivesplace',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'archivesroom',
            label: '档案室',
            langtag: 'entities.hrarchives.grid_001_grid.columns.archivesroom',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'activeflag',
            label: '是否有效',
            langtag: 'entities.hrarchives.grid_001_grid.columns.activeflag',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'borrowstate',
            label: '档案借阅状态',
            langtag: 'entities.hrarchives.grid_001_grid.columns.borrowstate',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
    ]

    /**
     * 获取表格行模型
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public getGridRowModel(){
        return {
          srfkey: new FormItemModel(),
        }
    }

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public rules: any = {
        srfkey: [
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '档案信息标识 值不能为空', trigger: 'change' },
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '档案信息标识 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 获取对应列class
     *
     * @type {*}
     * @memberof GRID_001Base
     */
    public hasRowEdit: any = {
        'archivescode':false,
        'hrorganizationname':false,
        'archivesplace':false,
        'archivesroom':false,
        'activeflag':false,
        'borrowstate':false,
    };

    /**
     * 获取对应列class
     *
     * @param {*} $args row 行数据，column 列数据，rowIndex 行索引，列索引
     * @returns {void}
     * @memberof GRID_001Base
     */
    public getCellClassName(args: {row: any, column: any, rowIndex: number, columnIndex: number}): any {
        return ( this.hasRowEdit[args.column.property] && this.actualIsOpenEdit ) ? "edit-cell" : "info-cell";
    }


    /**
     * 导出数据格式化
     *
     * @param {*} filterVal
     * @param {*} jsonData
     * @param {any[]} [codelistColumns=[]]
     * @returns {Promise<any>}
     * @memberof GRID_001GridBase
     */
    public async formatExcelData(filterVal: any, jsonData: any, codelistColumns?: any[]): Promise<any> {
        return super.formatExcelData(filterVal, jsonData, [
            {
                name: 'activeflag',
                srfkey: 'YesNo',
                codelistType : 'STATIC',
                renderMode: 'other',
                textSeparator: '、',
                valueSeparator: ',',
            },
            {
                name: 'borrowstate',
                srfkey: 'CL_HR_0024',
                codelistType : 'STATIC',
                renderMode: 'other',
                textSeparator: '、',
                valueSeparator: ',',
            },
        ]);
    }

}